==> percona-xtrabackup_8.4.0-5.orig.tar.gz: percona-xtrabackup-8.4.0-5/storage/innobase/xtrabackup/test/t/bug1630841.sh <==
#
# Bug 1630841: sha256 password doesn't work
#

require_server_version_higher_than 5.6.0

MYSQLD_EXTRA_MY_CNF_OPTS="
authentication-policy=sha256_password
ssl-ca=${PWD}/inc/ssl-certs/cacert.pem
ssl-cert=${PWD}/inc/ssl-certs/server-cert.pem
ssl-key=${PWD}/inc/ssl-certs/server-key.pem
"

start_server

vlog "*************************************************************************"
cat $MYSQLD_ERRFILE
vlog "*************************************************************************"

vlog "Detectiong SSL support"

if has_openssl
then
	vlog "Server is built with OpenSSL"
	SEVER_SSL=openssl
else
	vlog "Server is built with YaSSL"
	SEVER_SSL=yassl
fi

if ${XB_BIN} --param 2>/dev/null | grep -q server-public-key-path
then
	vlog "Xtrabackup is built with OpenSSL"
	XTRABACKUP_SSL=openssl
else
	vlog "Xtrabackup is built with YaSSL"
	XTRABACKUP_SSL=yassl
fi

# using SSL encryption requires xtrabackup and mysql to use the same SSL library
if [ "$SEVER_SSL" = "$XTRABACKUP_SSL" ]
then

vlog "Creating user 'pxb'"

mysql -e "CREATE USER pxb@'localhost' IDENTIFIED BY 'password1' REQUIRE SSL"
mysql -e "GRANT BACKUP_ADMIN, PROCESS, RELOAD, LOCK TABLES, REPLICATION CLIENT ON *.* TO pxb@'localhost'"
mysql -e "GRANT SELECT ON performance_schema.log_status TO pxb@'localhost'"
if is_server_version_higher_than 8.0.23
then
  mysql -e "GRANT SELECT ON performance_schema.keyring_component_status TO pxb@'localhost'"
fi
mysql -e "FLUSH PRIVILEGES"

vlog 'connecting with MYSQL cli'
run_cmd ${MYSQL} \
	--no-defaults \
	--user=pxb \
	--password=password1 \
	--host=127.0.0.1 \
	--port=${MYSQLD_PORT} \
	--ssl-ca=${PWD}/inc/ssl-certs/cacert.pem \
	--ssl-cert=${PWD}/inc/ssl-certs/client-cert.pem \
	--ssl-key=${PWD}/inc/ssl-certs/client-key.pem \
	-e '\s'

vlog 'connecting with xtrabackup'
run_cmd ${XB_BIN} \
	--no-defaults \
	--backup \
	--user=pxb \
	--password=password1 \
	--host=127.0.0.1 \
	--port=${MYSQLD_PORT} \
	--ssl-ca=${PWD}/inc/ssl-certs/cacert.pem \
	--ssl-cert=${PWD}/inc/ssl-certs/client-cert.pem \
	--ssl-key=${PWD}/inc/ssl-certs/client-key.pem \
	--target-dir=$topdir/backup1

fi

stop_server

vlog "*************************************************************************"
cat $MYSQLD_ERRFILE
vlog "*************************************************************************"

# sha256_password + asymmetric encryption requires OpenSSL
# both on server and xtrabackup

if [ "$SEVER_SSL" = "openssl" -a "$XTRABACKUP_SSL" = "openssl" ]
then

MYSQLD_EXTRA_MY_CNF_OPTS="
authentication-policy=sha256_password
sha256_password_private_key_path=${PWD}/inc/ssl-certs/rsa_private_key.pem
sha256_password_public_key_path=${PWD}/inc/ssl-certs/rsa_public_key.pem
"

start_server

mysql -e "CREATE USER pbx@'localhost' IDENTIFIED BY 'password1'"
mysql -e "GRANT BACKUP_ADMIN, PROCESS, RELOAD, LOCK TABLES, REPLICATION CLIENT ON *.* TO pbx@'localhost'"
mysql -e "GRANT SELECT ON performance_schema.log_status TO pbx@'localhost'"
if is_server_version_higher_than 8.0.23
then
  mysql -e "GRANT SELECT ON performance_schema.keyring_component_status TO pbx@'localhost'"
fi
mysql -e "FLUSH PRIVILEGES"

vlog 'connecting with MYSQL cli'
run_cmd ${MYSQL} \
	--no-defaults \
	--user=pbx \
	--password=password1 \
	--host=127.0.0.1 \
	--port=${MYSQLD_PORT} \
	-e '\s'

vlog 'connecting with xtrabackup'
run_cmd ${XB_BIN} \
	--no-defaults \
	--backup \
	--user=pbx \
	--password=password1 \
	--host=127.0.0.1 \
	--port=${MYSQLD_PORT} \
	--target-dir=$topdir/backup2

fi

==> percona-xtrabackup-80_8.0.23-16.orig.tar.gz: percona-xtrabackup-8.0.23-16/storage/innobase/xtrabackup/test/t/bug1630841.sh <==
#
# Bug 1630841: sha256 password doesn't work
#

require_server_version_higher_than 5.6.0

MYSQLD_EXTRA_MY_CNF_OPTS="
default-authentication-plugin=sha256_password
ssl-ca=${PWD}/inc/ssl-certs/cacert.pem
ssl-cert=${PWD}/inc/ssl-certs/server-cert.pem
ssl-key=${PWD}/inc/ssl-certs/server-key.pem
"

start_server

vlog "*************************************************************************"
cat $MYSQLD_ERRFILE
vlog "*************************************************************************"

vlog "Detectiong SSL support"

if has_openssl
then
	vlog "Server is built with OpenSSL"
	SEVER_SSL=openssl
else
	vlog "Server is built with YaSSL"
	SEVER_SSL=yassl
fi

if ${XB_BIN} --param 2>/dev/null | grep -q server-public-key-path
then
	vlog "Xtrabackup is built with OpenSSL"
	XTRABACKUP_SSL=openssl
else
	vlog "Xtrabackup is built with YaSSL"
	XTRABACKUP_SSL=yassl
fi

# using SSL encryption requires xtrabackup and mysql to use the same SSL library
if [ "$SEVER_SSL" = "$XTRABACKUP_SSL" ]
then

vlog "Creating user 'pxb'"

mysql -e "CREATE USER pxb@'localhost' IDENTIFIED BY 'password1' REQUIRE SSL"
mysql -e "GRANT BACKUP_ADMIN, PROCESS, RELOAD, LOCK TABLES, REPLICATION CLIENT ON *.* TO pxb@'localhost'"
mysql -e "GRANT SELECT ON performance_schema.log_status TO pxb@'localhost'"
mysql -e "FLUSH PRIVILEGES"

vlog 'connecting with MYSQL cli'
run_cmd ${MYSQL} \
	--no-defaults \
	--user=pxb \
	--password=password1 \
	--host=127.0.0.1 \
	--port=${MYSQLD_PORT} \
	--ssl-ca=${PWD}/inc/ssl-certs/cacert.pem \
	--ssl-cert=${PWD}/inc/ssl-certs/client-cert.pem \
	--ssl-key=${PWD}/inc/ssl-certs/client-key.pem \
	-e '\s'

vlog 'connecting with xtrabackup'
run_cmd ${XB_BIN} \
	--no-defaults \
	--backup \
	--user=pxb \
	--password=password1 \
	--host=127.0.0.1 \
	--port=${MYSQLD_PORT} \
	--ssl-ca=${PWD}/inc/ssl-certs/cacert.pem \
	--ssl-cert=${PWD}/inc/ssl-certs/client-cert.pem \
	--ssl-key=${PWD}/inc/ssl-certs/client-key.pem \
	--target-dir=$topdir/backup1

fi

stop_server

vlog "*************************************************************************"
cat $MYSQLD_ERRFILE
vlog "*************************************************************************"

# sha256_password + asymmetric encryption requires OpenSSL
# both on server and xtrabackup

if [ "$SEVER_SSL" = "openssl" -a "$XTRABACKUP_SSL" = "openssl" ]
then

MYSQLD_EXTRA_MY_CNF_OPTS="
default-authentication-plugin=sha256_password
sha256_password_private_key_path=${PWD}/inc/ssl-certs/rsa_private_key.pem
sha256_password_public_key_path=${PWD}/inc/ssl-certs/rsa_public_key.pem
"

start_server

mysql -e "CREATE USER pbx@'localhost' IDENTIFIED BY 'password1'"
mysql -e "GRANT BACKUP_ADMIN, PROCESS, RELOAD, LOCK TABLES, REPLICATION CLIENT ON *.* TO pbx@'localhost'"
mysql -e "GRANT SELECT ON performance_schema.log_status TO pbx@'localhost'"
mysql -e "FLUSH PRIVILEGES"

vlog 'connecting with MYSQL cli'
run_cmd ${MYSQL} \
	--no-defaults \
	--user=pbx \
	--password=password1 \
	--host=127.0.0.1 \
	--port=${MYSQLD_PORT} \
	-e '\s'

vlog 'connecting with xtrabackup'
run_cmd ${XB_BIN} \
	--no-defaults \
	--backup \
	--user=pbx \
	--password=password1 \
	--host=127.0.0.1 \
	--port=${MYSQLD_PORT} \
	--target-dir=$topdir/backup2

fi
